App

Struct App 

pub struct App {
Show 50 fields core: Core, about: About, nav_bar_context_id: Entity, nav_model: SingleSelectModel, tab_model: Model<SingleSelect>, config_handler: Option<Config>, state_handler: Option<Config>, config: Config, state: State, mode: Mode, app_themes: Vec<String>, compio_tx: Sender<Pin<Box<dyn Future<Output = ()> + Send>>>, context_page: ContextPage, dialog_pages: DialogPages, dialog_text_input: Id, key_binds: HashMap<KeyBind, Action>, margin: FxHashMap<Id, (f32, f32, f32, f32)>, mime_app_cache: MimeAppCache, modifiers: Modifiers, mounter_items: FxHashMap<MounterKey, Vec<MounterItem>>, client_items: FxHashMap<ClientKey, ClientItems>, must_save_sort_names: bool, network_drive_connecting: Option<(MounterKey, String)>, network_drive_input: String, remote_drive_connecting: Option<(ClientKey, String)>, remote_drive_input: String, pending_operation_id: u64, pending_operations: BTreeMap<u64, (Operation, Controller)>, progress_operations: BTreeSet<u64>, complete_operations: BTreeMap<u64, Operation>, failed_operations: BTreeMap<u64, (Operation, Controller, String)>, scrollable_id: Id, search_id: Id, size: Option<Size>, toasts: Toasts<Message>, watcher_opt: Option<(Debouncer<RecommendedWatcher, RecommendedCache>, FxHashSet<PathBuf>)>, windows: FxHashMap<Id, Window>, nav_dnd_hover: Option<(Location, Instant)>, tab_dnd_hover: Option<(Entity, Instant)>, type_select_prefix: String, type_select_last_key: Option<Instant>, nav_drag_id: DragId, tab_drag_id: DragId, auto_scroll_speed: Option<i16>, file_dialog_opt: Option<Dialog<Message>>, clipboard_cache: ClipboardCache, running_tasks: HashMap<usize, usize>, job_total_tasks: HashMap<usize, usize>, download_files_total: usize, download_files_done: usize,
}

Fields

core: Coreabout: Aboutnav_bar_context_id: Entitynav_model: SingleSelectModeltab_model: Model<SingleSelect>config_handler: Option<Config>state_handler: Option<Config>config: Configstate: Statemode: Modeapp_themes: Vec<String>compio_tx: Sender<Pin<Box<dyn Future<Output = ()> + Send>>>context_page: ContextPagedialog_pages: DialogPagesdialog_text_input: Idkey_binds: HashMap<KeyBind, Action>margin: FxHashMap<Id, (f32, f32, f32, f32)>mime_app_cache: MimeAppCachemodifiers: Modifiersmounter_items: FxHashMap<MounterKey, Vec<MounterItem>>client_items: FxHashMap<ClientKey, ClientItems>must_save_sort_names: boolnetwork_drive_connecting: Option<(MounterKey, String)>network_drive_input: Stringremote_drive_connecting: Option<(ClientKey, String)>remote_drive_input: Stringpending_operation_id: u64pending_operations: BTreeMap<u64, (Operation, Controller)>progress_operations: BTreeSet<u64>complete_operations: BTreeMap<u64, Operation>failed_operations: BTreeMap<u64, (Operation, Controller, String)>scrollable_id: Idsearch_id: Idsize: Option<Size>toasts: Toasts<Message>watcher_opt: Option<(Debouncer<RecommendedWatcher, RecommendedCache>, FxHashSet<PathBuf>)>windows: FxHashMap<Id, Window>nav_dnd_hover: Option<(Location, Instant)>tab_dnd_hover: Option<(Entity, Instant)>type_select_prefix: Stringtype_select_last_key: Option<Instant>nav_drag_id: DragIdtab_drag_id: DragIdauto_scroll_speed: Option<i16>file_dialog_opt: Option<Dialog<Message>>clipboard_cache: ClipboardCacherunning_tasks: HashMap<usize, usize>

Maps array_id -> current running task count (updated by poll)

job_total_tasks: HashMap<usize, usize>

Maps array_id -> total task count (set once on job submission, never overwritten)

download_files_total: usize

Total files queued across all active download batches

download_files_done: usize

Files completed so far across all active download batches

Implementations

Source

impl App

fn clipboard_has_content(&self) -> bool

Returns true if the clipboard cache contains pasteable content

fn push_dialog( &mut self, page: DialogPage, focus_id: Option<Id>, ) -> Task<Message>

fn open_file(&mut self, paths: &[impl AsRef<Path>]) -> Task<Message>

fn launch_from_mime_cache<P>(&self, mime: &Mime, paths: &[P]) -> bool
where P: Debug + AsRef<Path> + AsRef<OsStr>,

fn destination_selection_dialog( &mut self, paths: &[impl AsRef<Path>], on_result: impl Fn(DialogResult) -> Message + 'static, title: impl Into<String>, accept_label: impl AsRef<str>, ) -> Task<Message>

fn extract_to(&mut self, paths: &[impl AsRef<Path>]) -> Task<Message>

fn move_to(&mut self, paths: &[impl AsRef<Path>]) -> Task<Message>

fn copy_to(&mut self, paths: &[impl AsRef<Path>]) -> Task<Message>

fn download_to( &mut self, paths: &[impl AsRef<Path>], uris: &[String], ) -> Task<Message>

fn open_tab_entity( &mut self, location: Location, activate: bool, selection_paths: Option<Vec<PathBuf>>, scrollable_id: Id, window_id: Option<Id>, ) -> (Entity, Task<Message>)

fn open_tab( &mut self, location: Location, activate: bool, selection_paths: Option<Vec<PathBuf>>, ) -> Task<Message>

fn delete(&mut self, paths: impl IntoIterator<Item = PathBuf>) -> Task<Message>

fn operation(&mut self, operation: Operation) -> Task<Message>

fn join_operations(&mut self, operations: Vec<Operation>) -> Task<Message>

Will join operations together into a single task that will return a single Message::PendingResults message when all operations are complete.

fn handle_completed_operations( &mut self, completed: Vec<(u64, OperationSelection)>, ) -> Task<Message>

fn handle_operation_errors( &mut self, errors: Vec<(u64, OperationError)>, ) -> Task<Message>

fn remove_window(&mut self, id: &Id)

fn rescan_operation_selection( &mut self, op_sel: OperationSelection, ) -> Task<Message>

fn update_tab( &mut self, entity: Entity, location: Location, selection_paths: Option<Vec<PathBuf>>, ) -> Task<Message>

fn rescan_tab( &mut self, entity: Entity, location: Location, selection_paths: Option<Vec<PathBuf>>, ) -> Task<Message>

fn rescan_trash(&mut self) -> Task<Message>

fn rescan_recents(&mut self) -> Task<Message>

fn search_get(&self) -> Option<&str>

fn search_set_active(&mut self, term_opt: Option<String>) -> Task<Message>

fn search_set( &mut self, tab: Entity, term_opt: Option<String>, selection_paths: Option<Vec<PathBuf>>, ) -> Task<Message>

fn selected_paths( &self, entity_opt: Option<Entity>, ) -> impl Iterator<Item = PathBuf> + use<'_>

fn selected_delete_paths( &self, entity_opt: Option<Entity>, ) -> impl Iterator<Item = PathBuf> + use<'_>

fn selected_uris( &self, entity_opt: Option<Entity>, ) -> impl Iterator<Item = String> + use<'_>

fn set_cut(&mut self, entity_opt: Option<Entity>)

fn update_config(&mut self) -> Task<Message>

fn update_desktop(&mut self) -> Task<Message>

fn activate_nav_model_location(&mut self, location: &Location)

fn close_context_menus(&mut self) -> Task<Message>

fn update_nav_model(&mut self)

fn update_notification(&mut self) -> Task<Message>

fn update_title(&mut self) -> Task<Message>

fn update_watcher(&mut self) -> Task<Message>

fn network_drive(&self) -> Element<'_, Message>

fn remote_drive(&self) -> Element<'_, Message>

fn desktop_view_options(&self) -> Element<'_, Message>

fn edit_history(&self) -> Element<'_, Message>

fn preview<'a>( &'a self, entity_opt: &Option<Entity>, kind: &'a PreviewKind, context_drawer: bool, ) -> Element<'a, Message>

fn settings(&self) -> Element<'_, Message>

fn tb_settings(&self) -> Element<'_, Message>

fn update_favorites( &mut self, path_changes: &[(impl AsRef<Path>, impl AsRef<Path>)], ) -> bool